@@ -1,28 +1,15 @@
 /*
-   Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "importimapsettingsthunderbirdcheckjobtest.h"
 #include "importwizard/checks/importimapsettingsthunderbirdcheckjob.h"
 #include "libsieveeditor_export.h"
-#include <QTest>
-#include <QStandardPaths>
 #include <QSignalSpy>
+#include <QStandardPaths>
+#include <QTest>
 
 Q_DECLARE_METATYPE(SieveEditorUtil::SieveServerConfig)
 extern LIBSIEVEEDITOR_EXPORT QString sieveeditor_thunderbird_default_toplevel_path;
@@ -118,7 +105,8 @@ void ImportImapSettingsThunderbirdCheckJobTest::shouldImportSieveSettings_data()
         settings.sieveSettings.serverName = QStringLiteral("sever.foo.org");
         settings.sieveSettings.port = 4190;
 
-        QTest::newRow("thunderbirdencryptionnoneoneaccount") << QStringLiteral("/thunderbirdencryptionnoneoneaccount") << QStringLiteral("bla@kde.org") << settings;
+        QTest::newRow("thunderbirdencryptionnoneoneaccount")
+            << QStringLiteral("/thunderbirdencryptionnoneoneaccount") << QStringLiteral("bla@kde.org") << settings;
     }
     {
         SieveEditorUtil::SieveServerConfig settings;
@@ -131,7 +119,8 @@ void ImportImapSettingsThunderbirdCheckJobTest::shouldImportSieveSettings_data()
         settings.sieveSettings.serverName = QStringLiteral("sever.foo.org");
         settings.sieveSettings.port = 4190;
 
-        QTest::newRow("thunderbirdencryptionssloneaccount") << QStringLiteral("/thunderbirdencryptionssloneaccount") << QStringLiteral("bla@kde.org") << settings;
+        QTest::newRow("thunderbirdencryptionssloneaccount")
+            << QStringLiteral("/thunderbirdencryptionssloneaccount") << QStringLiteral("bla@kde.org") << settings;
     }
 
     {
@@ -145,7 +134,8 @@ void ImportImapSettingsThunderbirdCheckJobTest::shouldImportSieveSettings_data()
         settings.sieveSettings.serverName = QStringLiteral("sever.foo.org");
         settings.sieveSettings.port = 4190;
 
-        QTest::newRow("thunderbirdencryptionstarttlsoneaccount") << QStringLiteral("/thunderbirdencryptionstarttlsoneaccount") << QStringLiteral("bla@kde.org") << settings;
+        QTest::newRow("thunderbirdencryptionstarttlsoneaccount")
+            << QStringLiteral("/thunderbirdencryptionstarttlsoneaccount") << QStringLiteral("bla@kde.org") << settings;
     }
 }
 
