@@ -1,33 +1,21 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SERVERSIEVESETTINGS_H
-#define SERVERSIEVESETTINGS_H
+#pragma once
 
-#include <QWidget>
-#include "sieveeditorutil.h"
 #include "libsieveeditor_private_export.h"
+#include "sieveeditorutil.h"
+#include <QWidget>
 
-namespace Ui {
+namespace Ui
+{
 class ServerSieveSettings;
 }
-namespace MailTransport {
+namespace MailTransport
+{
 class ServerTest;
 }
 class QComboBox;
@@ -77,6 +65,7 @@ private:
 
     void slotFinished(const QVector<int> &testResult);
     void slotEncryptionRadioChanged();
+
 private:
     void populateDefaultAuthenticationOptions(QComboBox *combobox);
     void slotSafetyChanged();
@@ -85,4 +74,3 @@ private:
     MailTransport::ServerTest *mServerTest = nullptr;
 };
 
-#endif // SERVERSIEVESETTINGS_H
