@@ -1,25 +1,12 @@
 /*
-   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "sieveeditorpagewidget.h"
-#include <KSieveUi/CheckScriptJob>
 #include "sieveeditorglobalconfig.h"
+#include <KSieveUi/CheckScriptJob>
 
 #include <KManageSieve/SieveJob>
 
@@ -32,7 +19,7 @@
 SieveEditorPageWidget::SieveEditorPageWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *vbox = new QVBoxLayout(this);
+    auto vbox = new QVBoxLayout(this);
     mSieveEditorWidget = new KSieveUi::SieveEditorWidget(false);
     connect(mSieveEditorWidget, &KSieveUi::SieveEditorWidget::valueChanged, this, &SieveEditorPageWidget::slotValueChanged);
     vbox->addWidget(mSieveEditorWidget);
@@ -56,7 +43,7 @@ void SieveEditorPageWidget::slotCheckSyntaxClicked()
     }
     mSieveEditorWidget->addNormalMessage(i18n("Uploading script to server for checking it, please wait..."));
 
-    auto *checkScriptJob = new KSieveUi::CheckScriptJob(this);
+    auto checkScriptJob = new KSieveUi::CheckScriptJob(this);
     connect(checkScriptJob, &KSieveUi::CheckScriptJob::finished, this, &SieveEditorPageWidget::slotCheckScriptJobFinished);
     checkScriptJob->setUrl(mCurrentURL);
     checkScriptJob->setIsActive(mWasActive);
@@ -147,8 +134,7 @@ void SieveEditorPageWidget::slotPutResult(KManageSieve::SieveJob *job, bool succ
     }
     if (success) {
         if (job->property("showuploadinformation").toBool()) {
-            KMessageBox::information(this, i18n("The Sieve script was successfully uploaded."),
-                                     i18n("Sieve Script Upload"));
+            KMessageBox::information(this, i18n("The Sieve script was successfully uploaded."), i18n("Sieve Script Upload"));
         }
         mIsNewScript = false;
         mSieveEditorWidget->updateOriginalScript();
@@ -162,7 +148,8 @@ void SieveEditorPageWidget::slotPutResult(KManageSieve::SieveJob *job, bool succ
         if (!msg.isEmpty()) {
             KMessageBox::error(this,
                                i18n("Uploading the Sieve script failed.\n"
-                                    "The server responded:\n%1", msg),
+                                    "The server responded:\n%1",
+                                    msg),
                                i18n("Sieve Error"));
         } else {
             KMessageBox::error(this,
