@@ -1,31 +1,18 @@
 /*
-   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "sieveeditortabwidget.h"
 
-#include <KLocalizedString>
 #include <KActionCollection>
-#include <QMenu>
+#include <KLocalizedString>
 #include <QIcon>
+#include <QMenu>
 
-#include <QTabBar>
 #include <QAction>
+#include <QTabBar>
 
 SieveEditorTabWidget::SieveEditorTabWidget(KActionCollection *ac, QWidget *parent)
     : QTabWidget(parent)
@@ -69,7 +56,7 @@ void SieveEditorTabWidget::slotTabContextMenuRequest(const QPoint &pos)
 
     QAction *action = menu.exec(mapToGlobal(pos));
 
-    if (action == allOther) {   // Close all other tabs
+    if (action == allOther) { // Close all other tabs
         Q_EMIT tabRemoveAllExclude(indexBar);
     } else if (action == closeTab) {
         Q_EMIT tabCloseRequestedIndex(indexBar);
@@ -83,7 +70,7 @@ void SieveEditorTabWidget::initActions(KActionCollection *ac)
     if (ac) {
         QAction *closeCurrentTabAct = new QAction(i18nc("@action:inmenu", "Close Tab"), this);
         ac->addAction(QStringLiteral("close_current_tab"), closeCurrentTabAct);
-        ac->setDefaultShortcut(closeCurrentTabAct, QKeySequence(Qt::CTRL + Qt::Key_W));
+        ac->setDefaultShortcut(closeCurrentTabAct, QKeySequence(Qt::CTRL | Qt::Key_W));
         closeCurrentTabAct->setIcon(QIcon::fromTheme(QStringLiteral("tab-close")));
         connect(closeCurrentTabAct, &QAction::triggered, this, &SieveEditorTabWidget::slotCloseCurrentTab);
     }
